==> gtk+-3.89.1.tar.xz: gtk+-3.89.1/gsk/gskrendererprivate.h <==
/* GSK - The GTK Scene Kit
 *
 * Copyright 2016  Endless
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GSK_RENDERER_PRIVATE_H__
#define __GSK_RENDERER_PRIVATE_H__

#include "gskrenderer.h"
#include "gskprofilerprivate.h"

G_BEGIN_DECLS

#define GSK_RENDERER_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), GSK_TYPE_RENDERER, GskRendererClass))
#define GSK_IS_RENDERER_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GSK_TYPE_RENDERER))
#define GSK_RENDERER_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), GSK_TYPE_RENDERER, GskRendererClass))

struct _GskRenderer
{
  GObject parent_instance;
};

struct _GskRendererClass
{
  GObjectClass parent_class;

  gboolean (* realize) (GskRenderer *renderer);
  void (* unrealize) (GskRenderer *renderer);

  void (* render) (GskRenderer *renderer,
                   GskRenderNode *root);

  cairo_surface_t * (* create_cairo_surface) (GskRenderer *renderer,
                                              cairo_format_t,
                                              int width,
                                              int height);
};

gboolean gsk_renderer_is_realized (GskRenderer *renderer);

GskRenderNode *         gsk_renderer_get_root_node              (GskRenderer    *renderer);
GdkDrawingContext *     gsk_renderer_get_drawing_context        (GskRenderer    *renderer);
cairo_t *               gsk_renderer_get_cairo_context          (GskRenderer    *renderer);
cairo_surface_t *       gsk_renderer_create_cairo_surface       (GskRenderer    *renderer,
                                                                 cairo_format_t  format,
                                                                 int             width,
                                                                 int             height);

GskProfiler *           gsk_renderer_get_profiler               (GskRenderer    *renderer);

G_END_DECLS

#endif /* __GSK_RENDERER_PRIVATE_H__ */

==> gtk+-3.89.2.tar.xz: gtk+-3.89.2/gsk/gskrendererprivate.h <==
/* GSK - The GTK Scene Kit
 *
 * Copyright 2016  Endless
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GSK_RENDERER_PRIVATE_H__
#define __GSK_RENDERER_PRIVATE_H__

#include "gskrenderer.h"
#include "gskprofilerprivate.h"

G_BEGIN_DECLS

#define GSK_RENDERER_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), GSK_TYPE_RENDERER, GskRendererClass))
#define GSK_IS_RENDERER_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GSK_TYPE_RENDERER))
#define GSK_RENDERER_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), GSK_TYPE_RENDERER, GskRendererClass))

struct _GskRenderer
{
  GObject parent_instance;
};

struct _GskRendererClass
{
  GObjectClass parent_class;

  gboolean (* realize) (GskRenderer *renderer,
                        GdkWindow *window,
                        GError **error);
  void (* unrealize) (GskRenderer *renderer);

  GdkDrawingContext * (* begin_draw_frame) (GskRenderer *renderer,
                                            const cairo_region_t *region);
  void (* end_draw_frame) (GskRenderer *renderer,
                           GdkDrawingContext *context);
  void (* render) (GskRenderer *renderer,
                   GskRenderNode *root);

  cairo_surface_t * (* create_cairo_surface) (GskRenderer *renderer,
                                              cairo_format_t,
                                              int width,
                                              int height);
};

gboolean gsk_renderer_is_realized (GskRenderer *renderer);

GskRenderNode *         gsk_renderer_get_root_node              (GskRenderer    *renderer);
GdkDrawingContext *     gsk_renderer_get_drawing_context        (GskRenderer    *renderer);
cairo_surface_t *       gsk_renderer_create_cairo_surface       (GskRenderer    *renderer,
                                                                 cairo_format_t  format,
                                                                 int             width,
                                                                 int             height);

GskProfiler *           gsk_renderer_get_profiler               (GskRenderer    *renderer);

G_END_DECLS

#endif /* __GSK_RENDERER_PRIVATE_H__ */
